package org.adamgulczynski;

import java.util.*;

import io.github.cdimascio.dotenv.Dotenv;

public class Main {

    public static void main(String[] args) {

        // get env variables
        Dotenv dotenv = Dotenv.load();
        String basePath = dotenv.get("BASE_PATH");
        String apiKey = dotenv.get("API_KEY");

        // read city details from json file
        JsonReader readJSON = new JsonReader();
        Map<String, Map<String, Double>> cityDataMap = readJSON.readFile(basePath + "data.json");

        // print available cities
        System.out.println("Dostepne miasta:");
        readJSON.printEntries();

        DataFetcher dataFetcher = new DataFetcher(apiKey);

        Scanner scanner = new Scanner(System.in);

        List<WeatherData> weatherDataList = new ArrayList<>();

        while (true) {
            System.out.print("P-Podaj miasto, Z-Zakoncz: ");
            String userInput = scanner.nextLine();

            if (Objects.equals(userInput, "P") || Objects.equals(userInput, "p")) {
                String chosenCity = scanner.nextLine().toLowerCase();
                Map<String, Double> chosenCityData = (Map<String, Double>) cityDataMap.get(chosenCity);
                if (cityDataMap.containsKey(chosenCity)) {
                    double latitude = (double) chosenCityData.get("latitude");
                    double longitude = (double) chosenCityData.get("longitude");

                    String weatherDataString;
                    try {
                        weatherDataString = dataFetcher.fetchWeather(latitude, longitude);
                    } catch (IllegalArgumentException e) {
                        System.out.println("Niepoprawne dane w pliku json");
                        continue;
                    }

                    System.out.println(weatherDataString);

                    // convert to WeatherData object
                    WeatherData weatherData = WeatherParser.parseWeatherToWeatherData(weatherDataString);

                    // display the data
                    System.out.println(weatherData);

                    // add data to a list, will be written to the file
                    weatherDataList.add(weatherData);
                } else {
                    System.out.println("Nie ma takiego miasta.");
                }
            } else if (Objects.equals(userInput, "Z") || Objects.equals(userInput, "z")) {
                label:
                while (true) {
                    System.out.println("Do jakiego pliku chcesz zapisac dane? xml/json/pdf");
                    String userChoice = scanner.nextLine().toLowerCase();

                    String path = basePath + "weather";

                    switch (userChoice) {
                        case "xml":
                            WeatherData.writeToXmlFile(path, weatherDataList);
                            break label;
                        case "json":
                            WeatherData.writeToJsonFile(path, weatherDataList);
                            break label;
                        case "pdf":
                            WeatherData.writeToPdfFile(path, weatherDataList);
                            break label;
                        default:
                            System.out.println("Bledny format.");
                            break;
                    }

                }

                break;
            } else {
                System.out.println("Bledna wartosc, podaj 'P' lub 'Z'");
            }
        }

        scanner.close();

    }

}