package org.adamgulczynski;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.core.util.DefaultPrettyPrinter;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.ObjectWriter;
import com.fasterxml.jackson.dataformat.xml.XmlMapper;

import java.io.*;

import com.lowagie.text.*;
import com.lowagie.text.pdf.*;

import java.util.List;

public class WeatherData {
    @JsonProperty("miasto")
    private final String city;

    @JsonProperty("temperatura")
    private final double temperature;

    @JsonProperty("wilgotnosc")
    private final int humidity;

    @JsonProperty("wiatr")
    private final double windSpeed;

    @JsonProperty("zachmurzenie")
    private final int clouds;

    @JsonProperty("cisnienie")
    private final int pressure;

    public WeatherData(String city, double temperature, int humidity, double windSpeed, int clouds, int pressure) {
        this.city = city;
        this.temperature = temperature;
        this.humidity = humidity;
        this.windSpeed = windSpeed;
        this.clouds = clouds;
        this.pressure = pressure;
    }

    @Override
    public String toString() {
        return "Miasto: " + city + '\n' +
                "Temperatura: " + temperature + " K\n" +
                "Cisnienie: " + pressure + " hPa\n" +
                "Wilgotnosc: " + humidity + "%\n" +
                "Wiatr: " + windSpeed + " m/s\n" +
                "Zachmurzenie: " + clouds + " %\n\n";
    }

    public String getCity() {
        return city;
    }

    public double getTemperature() {
        return temperature;
    }

    public int getHumidity() {
        return humidity;
    }

    public double getWindSpeed() {
        return windSpeed;
    }

    public int getClouds() {
        return clouds;
    }

    public int getPressure() {
        return pressure;
    }

    public static void writeToJsonFile(String filePath, List<WeatherData> weatherDataList) {
        ObjectMapper objectMapper = new ObjectMapper();

        String path = filePath + ".json";
        try {
            File file = new File(path);
            ObjectWriter objectWriter = objectMapper.writer(new DefaultPrettyPrinter());
            objectWriter.writeValue(file, weatherDataList);

            System.out.println("Dane zapisane do: " + path);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static void writeToXmlFile(String filePath, List<WeatherData> weatherDataList) {
        XmlMapper xmlMapper = new XmlMapper();

        String path = filePath + ".xml";
        try {
            File file = new File(path);
            ObjectWriter objectWriter = xmlMapper.writerWithDefaultPrettyPrinter();
            objectWriter.writeValue(file, weatherDataList);

            System.out.println("Dane zapisane do: " + path);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private static void writeToTxtFile(String filePath, List<WeatherData> weatherDataList) {
        StringBuilder content = new StringBuilder();
        for (WeatherData data : weatherDataList) {
            content.append(data.toString());
        }

        try (BufferedWriter writer = new BufferedWriter(new FileWriter(filePath + ".txt"))) {
            writer.write(content.toString());
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static void writeToPdfFile(String filePath, List<WeatherData> weatherDataList) {
        // create .txt file
        writeToTxtFile(filePath, weatherDataList);

        BufferedReader input = null;
        Document output = null;
        try {
            input = new BufferedReader(new FileReader(filePath + ".txt"));
            output = new Document(PageSize.LETTER, 40, 40, 40, 40);

            filePath = filePath + ".pdf";
            PdfWriter.getInstance(output, new FileOutputStream(filePath));

            output.open();
            output.addAuthor("Adam Gulczynski");
            output.addSubject("Projekt");
            output.addTitle("Projekt");

            String line = "";
            while (null != (line = input.readLine())) {
                System.out.println(line);
                Paragraph p = new Paragraph(line);
                p.setAlignment(Element.ALIGN_JUSTIFIED);
                output.add(p);
            }
            System.out.println("Dane zapisane do: " + filePath);
            output.close();
            input.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}