import org.adamgulczynski.DataFetcher;
import org.adamgulczynski.WeatherData;
import org.adamgulczynski.WeatherParser;
import org.junit.jupiter.api.Test;

import java.io.IOException;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;


class WeatherDataTest {

    @Test
    void testWeatherRequestWithGoodCoordinates() throws IOException {
        String sampleBody = """
                {
                  "name": "london",
                  "main": {
                    "temp": 280.95,
                    "humidity": 79,
                    "pressure": 1038
                  },
                  "wind": {
                    "speed": 4.12
                  },
                  "clouds": {
                    "all": 100
                  }
                }
                """;

        DataFetcher mockDataFetcher = mock(DataFetcher.class);

        double lat = 12.2;
        double lon = 22.3;
        when(mockDataFetcher.fetchWeather(lat, lon))
                .thenReturn(sampleBody);

        WeatherData weatherData = WeatherParser.parseWeatherToWeatherData(mockDataFetcher.fetchWeather(lat, lon));

        assertEquals(weatherData.getTemperature(), 280.95);
        assertEquals(weatherData.getHumidity(), 79);
        assertEquals(weatherData.getWindSpeed(), 4.12);
        assertEquals(weatherData.getPressure(), 1038);
        assertEquals(weatherData.getClouds(), 100);
    }

    @Test
    void testWeatherRequestWithValidCoordinates() throws IOException {
        String sampleBody = """
                {
                "name": "london",
                  "main": {
                    "temp": 280.95,
                    "humidity": 79,
                    "pressure": 1038
                  },
                  "wind": {
                    "speed": 4.12
                  },
                  "clouds": {
                    "all": 100
                  }
                }
                """;

        DataFetcher mockDataFetcher = mock(DataFetcher.class);

        double lat = 12.2;
        double lon = 22.3;
        when(mockDataFetcher.fetchWeather(lat, lon))
                .thenReturn(sampleBody);

        WeatherData weatherData = WeatherParser.parseWeatherToWeatherData(mockDataFetcher.fetchWeather(lat, lon));

        assertEquals(weatherData.getTemperature(), 280.95);
        assertEquals(weatherData.getHumidity(), 79);
        assertEquals(weatherData.getWindSpeed(), 4.12);
        assertEquals(weatherData.getPressure(), 1038);
        assertEquals(weatherData.getClouds(), 100);
    }

    @Test
    void testWeatherRequestWithInvalidLatitude() {
        DataFetcher mockDataFetcher = new DataFetcher("tes");

        // Using invalid coordinates
        double invalidLat = 500.0;
        double validLon = 22.3;

        assertThrows(IllegalArgumentException.class, () -> {
            mockDataFetcher.fetchWeather(invalidLat, validLon);
        });
    }

    @Test
    void testWeatherRequestWithInvalidLongitude() {
        DataFetcher mockDataFetcher = new DataFetcher("tes");

        // Using invalid coordinates
        double validLat = 20.0;
        double invalidLon = 522.3;

        assertThrows(IllegalArgumentException.class, () -> {
            mockDataFetcher.fetchWeather(validLat, invalidLon);
        });
    }
}