package org.example;

import com.sun.jdi.request.StepRequest;
import org.hibernate.Session;
import org.hibernate.query.Query;

import java.time.ZonedDateTime;

import java.util.List;

public class MyQuery {

    Session session;

    public MyQuery(Session session) {
        this.session = session;
    }

    // ========================  SELECTing from the database  =================================
    public List<Object[]> getBookByExactTitle(String title) {
        String q = "SELECT b.id, b.title " +
                "FROM Book b " +
                "WHERE b.title = :title";

        Query<Object[]> query = session.createQuery(q, Object[].class)
                .setParameter("title", title);

        for (Object[] result : query.getResultList()) {
            System.out.println("id = " + result[0]);
            System.out.println("title = " + result[1]);
        }

        return query.getResultList();
    }

    public List<Object[]> getBookDetailsWithAuthorByTitle(String title) {

        String q = "SELECT " +
                "bd.details_id, bd.page_count, bd.isbn, " +
                "b.title AS book_title, " +
                "a.name AS author_name " +
                "FROM book_details bd " +
                "JOIN books b ON bd.book_id = b.id " +
                "JOIN authors a ON bd.author_id = a.author_id " +
                "WHERE b.title = :given_title";

        Query<Object[]> query = session.createNativeQuery(q, Object[].class)
                .setParameter("given_title", title);
        List<Object[]> resultList = query.getResultList();

        for (Object[] result : resultList) {
            System.out.println("details_id = " + result[0]);
            System.out.println("page_count = " + result[1]);
            System.out.println("isbn = " + result[2]);
            System.out.println("book_title = " + result[3]);
            System.out.println("author_name = " + result[4]);
        }
        System.out.println("--------------------------");

        return resultList;
    }

    public List<Object[]> getBookReviewsByBookId(Long id, int page, int pageSize) {

        // calculate LIMIT and OFFSET
        int limit = pageSize;
        int offset = (page - 1) * pageSize;

        String q = "SELECT * " +
                "FROM reviews " +
                "WHERE book_id = :given_id " +
                "LIMIT :limt " +
                "OFFSET :offst";

        Query<Object[]> query = session.createNativeQuery(q, Object[].class)
                .setParameter("given_id", id)
                .setParameter("limt", limit)
                .setParameter("offst", offset);
        List<Object[]> resultList = query.getResultList();

        if (resultList.isEmpty()) {
            System.out.println("No reviews found for the given book id and page.");
            return null;
        }

        for (Object[] result : resultList) {
            System.out.println("review_id = " + result[0]);
            System.out.println("book_id = " + result[1]);
            System.out.println("rating = " + result[2]);
            System.out.println("review_text = " + result[3]);
            System.out.println("author_name = " + result[4]);
        }
        System.out.println("--------------------------");

        return resultList;
    }
    // ========================  END of SELECTing  =================================


    // ========================  INSERTing into the database  =================================
    public static Book createBook(String bookTitle) {
        Book book = new Book();
        book.setTitle(bookTitle);

        return book;
    }

    public static Author createAuthor(String authorName) {
        Author author = new Author();
        author.setName(authorName);
        return author;
    }

    public static BookDetails createBookDetails(String isbn, int pageCount, Book book, Author author) {
        BookDetails bookDetails = new BookDetails();

        bookDetails.setAuthor(author);
        bookDetails.setBook(book);
        bookDetails.setIsbn(isbn);
        bookDetails.setPageCount(pageCount);
        return bookDetails;
    }

    public static Review createReview(int rating, String reviewText, Book book, String authorName) {
        Review review = new Review();
        review.setBook(book);
        review.setRating(rating);
        review.setReviewText(reviewText);
        review.setAuthorName(authorName);

        ZonedDateTime currentTime = ZonedDateTime.now();
        review.setCreatedAt(currentTime);

        return review;
    }

    // ========================  END of INSERTing  =================================
}
